# horsetalk

[![PyPI version](https://badge.fury.io/py/horsetalk.svg)](https://badge.fury.io/py/horsetalk)
![GitHub last commit (master)](https://img.shields.io/github/last-commit/peaky76/horsetalk/master)
![GitHub repo size](https://img.shields.io/github/repo-size/:user/:repo)

A library of enums and parsers for common horseracing terminology
